@@ -11,6 +11,7 @@ from pyspark.ml.util import DefaultParamsReadable, DefaultParamsWritable
 
 # noinspection PyPackageRequirements
 from pyspark.sql.dataframe import DataFrame
+from typing_extensions import final
 
 from spark_pipeline_framework.logger.yarn_logger import get_logger
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
@@ -52,14 +53,10 @@ class FrameworkTransformer(
         return self._set(**kwargs)
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring, PyUnusedLocal,Mypy
+    @final
     def setParams(self, **kwargs: Any) -> Any:
         # ignore any parameters
-        kwargs = {
-            key: value
-            for key, value in kwargs.items()
-            if key not in ["progress_logger", "parameters"]
-            and not isinstance(value, dict)
-        }
+        kwargs = {key: value for key, value in kwargs.items() if self.hasParam(key)}
         return self._set(**kwargs)
 
     def _transform(self, df: DataFrame) -> DataFrame:
@@ -108,36 +105,8 @@ class FrameworkTransformer(
         # noinspection PyUnresolvedReferences,PyProtectedMember
         super()._setDefault(**kwargs)  # type: ignore
 
-    # # This is here to avoid mypy from complaining since this is a protected member
-    # # @property
-    # # def _input_kwargs(self) -> Dict[str, Any]:
-    # #     return self._input_kwargs
-    #
     def _set(self, **kwargs: Any) -> None:
+        # filter out any args that don't have parameters
+        kwargs = {key: value for key, value in kwargs.items() if self.hasParam(key)}
         # noinspection PyUnresolvedReferences,PyProtectedMember
         super()._set(**kwargs)  # type: ignore
-
-    # # noinspection PyPep8Naming
-    # @property
-    # def _paramMap(self):
-    #     # noinspection PyUnresolvedReferences,PyProtectedMember
-    #     return super()._paramMap  # type: ignore
-    #
-    # # noinspection PyPep8Naming
-    # @_paramMap.setter
-    # def _paramMap(self, p):
-    #     # noinspection PyUnresolvedReferences,PyProtectedMember
-    #     super()._paramMap = p  # type: ignorer
-
-    # This is here to avoid mypy from complaining since this is a protected member
-    # noinspection PyPep8Naming
-    # def _setDefault(self, **kwargs: Any) -> None:
-    #     ...
-
-    # This is here to avoid mypy from complaining since this is a protected member
-    # _input_kwargs: Dict[str, Any]
-
-    # def _set(self, **kwargs: Any) -> None:
-    #     ...
-
-    # _paramMap: Dict[Param[Any], Any]
